==> aws-cdk-scala-pinpointemail_3-0.1.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"pinpointemail","t":"pinpointemail","d":"","k":"static"},
{"l":"io/burkard/cdk/services/pinpointemail.html","n":"io.burkard.cdk.services.pinpointemail","t":"package io.burkard.cdk.services.pinpointemail","d":"io/burkard/cdk/services/pinpointemail","k":"package"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$.html","n":"CfnConfigurationSet","t":"object CfnConfigurationSet","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$.html","n":"apply","t":"def apply(internalResourceId: String, name: Option[String], tags: Option[List[_ <: TagsProperty]], reputationOptions: Option[ReputationOptionsProperty], trackingOptions: Option[TrackingOptionsProperty], sendingOptions: Option[SendingOptionsProperty], deliveryOptions: Option[DeliveryOptionsProperty])(implicit stackCtx: Stack): CfnConfigurationSet","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$.html","n":"CfnConfigurationSetEventDestination","t":"object CfnConfigurationSetEventDestination","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$.html","n":"apply","t":"def apply(internalResourceId: String, eventDestinationName: Option[String], configurationSetName: Option[String], eventDestination: Option[EventDestinationProperty])(implicit stackCtx: Stack): CfnConfigurationSetEventDestination","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$.html","n":"CfnConfigurationSetEventDestinationProps","t":"object CfnConfigurationSetEventDestinationProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$.html","n":"apply","t":"def apply(eventDestinationName: Option[String], configurationSetName: Option[String], eventDestination: Option[EventDestinationProperty]): CfnConfigurationSetEventDestinationProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$.html","n":"CfnConfigurationSetProps","t":"object CfnConfigurationSetProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$.html","n":"apply","t":"def apply(name: Option[String], tags: Option[List[_ <: TagsProperty]], reputationOptions: Option[ReputationOptionsProperty], trackingOptions: Option[TrackingOptionsProperty], sendingOptions: Option[SendingOptionsProperty], deliveryOptions: Option[DeliveryOptionsProperty]): CfnConfigurationSetProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$.html","n":"CfnDedicatedIpPool","t":"object CfnDedicatedIpPool","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$.html","n":"apply","t":"def apply(internalResourceId: String, tags: Option[List[_ <: TagsProperty]], poolName: Option[String])(implicit stackCtx: Stack): CfnDedicatedIpPool","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$.html","n":"CfnDedicatedIpPoolProps","t":"object CfnDedicatedIpPoolProps","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$.html","n":"apply","t":"def apply(tags: Option[List[_ <: TagsProperty]], poolName: Option[String]): CfnDedicatedIpPoolProps","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentity$.html","n":"CfnIdentity","t":"object CfnIdentity","d":"io/burkard/cdk/services/pinpointemail/CfnIdentity$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentity$.html","n":"apply","t":"def apply(internalResourceId: String, mailFromAttributes: Option[MailFromAttributesProperty], tags: Option[List[_ <: TagsProperty]], name: Option[String], feedbackForwardingEnabled: Option[Boolean], dkimSigningEnabled: Option[Boolean])(implicit stackCtx: Stack): CfnIdentity","d":"io/burkard/cdk/services/pinpointemail/CfnIdentity$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$.html","n":"CfnIdentityProps","t":"object CfnIdentityProps","d":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$.html","n":"apply","t":"def apply(mailFromAttributes: Option[MailFromAttributesProperty], tags: Option[List[_ <: TagsProperty]], name: Option[String], feedbackForwardingEnabled: Option[Boolean], dkimSigningEnabled: Option[Boolean]): CfnIdentityProps","d":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$.html","n":"CloudWatchDestinationProperty","t":"object CloudWatchDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$.html","n":"apply","t":"def apply(dimensionConfigurations: Option[List[_]]): CloudWatchDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$.html","n":"DeliveryOptionsProperty","t":"object DeliveryOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$.html","n":"apply","t":"def apply(sendingPoolName: Option[String]): DeliveryOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$.html","n":"DimensionConfigurationProperty","t":"object DimensionConfigurationProperty","d":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$.html","n":"apply","t":"def apply(defaultDimensionValue: Option[String], dimensionValueSource: Option[String], dimensionName: Option[String]): DimensionConfigurationProperty","d":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$.html","n":"EventDestinationProperty","t":"object EventDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$.html","n":"apply","t":"def apply(pinpointDestination: Option[PinpointDestinationProperty], kinesisFirehoseDestination: Option[KinesisFirehoseDestinationProperty], enabled: Option[Boolean], cloudWatchDestination: Option[CloudWatchDestinationProperty], matchingEventTypes: Option[List[String]], snsDestination: Option[SnsDestinationProperty]): EventDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$.html","n":"KinesisFirehoseDestinationProperty","t":"object KinesisFirehoseDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$.html","n":"apply","t":"def apply(deliveryStreamArn: Option[String], iamRoleArn: Option[String]): KinesisFirehoseDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$.html","n":"MailFromAttributesProperty","t":"object MailFromAttributesProperty","d":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$.html","n":"apply","t":"def apply(mailFromDomain: Option[String], behaviorOnMxFailure: Option[String]): MailFromAttributesProperty","d":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$.html","n":"PinpointDestinationProperty","t":"object PinpointDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$.html","n":"apply","t":"def apply(applicationArn: Option[String]): PinpointDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$.html","n":"ReputationOptionsProperty","t":"object ReputationOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$.html","n":"apply","t":"def apply(reputationMetricsEnabled: Option[Boolean]): ReputationOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$.html","n":"SendingOptionsProperty","t":"object SendingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$.html","n":"apply","t":"def apply(sendingEnabled: Option[Boolean]): SendingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$.html","n":"SnsDestinationProperty","t":"object SnsDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$.html","n":"apply","t":"def apply(topicArn: Option[String]): SnsDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/TagsProperty$.html","n":"TagsProperty","t":"object TagsProperty","d":"io/burkard/cdk/services/pinpointemail/TagsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/TagsProperty$.html","n":"apply","t":"def apply(key: Option[String], value: Option[String]): TagsProperty","d":"io/burkard/cdk/services/pinpointemail/TagsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$.html","n":"TrackingOptionsProperty","t":"object TrackingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$.html","n":"apply","t":"def apply(customRedirectDomain: Option[String]): TrackingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$","k":"def"},
{"l":"docs/index.html","n":"pinpointemail","t":"pinpointemail","d":"","k":"static"}];

==> aws-cdk-scala-pinpointemail_3-0.2.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"pinpointemail","t":"pinpointemail","d":"","k":"static"},
{"l":"io/burkard/cdk/services/pinpointemail.html","n":"io.burkard.cdk.services.pinpointemail","t":"package io.burkard.cdk.services.pinpointemail","d":"io/burkard/cdk/services/pinpointemail","k":"package"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$.html","n":"CfnConfigurationSet","t":"object CfnConfigurationSet","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, tags: Option[List[_ <: TagsProperty]], reputationOptions: Option[ReputationOptionsProperty], trackingOptions: Option[TrackingOptionsProperty], sendingOptions: Option[SendingOptionsProperty], deliveryOptions: Option[DeliveryOptionsProperty])(implicit stackCtx: Stack): CfnConfigurationSet","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSet$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$.html","n":"CfnConfigurationSetEventDestination","t":"object CfnConfigurationSetEventDestination","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$.html","n":"apply","t":"def apply(internalResourceId: String, eventDestinationName: String, configurationSetName: String, eventDestination: Option[EventDestinationProperty])(implicit stackCtx: Stack): CfnConfigurationSetEventDestination","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestination$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$.html","n":"CfnConfigurationSetEventDestinationProps","t":"object CfnConfigurationSetEventDestinationProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$.html","n":"apply","t":"def apply(eventDestinationName: String, configurationSetName: String, eventDestination: Option[EventDestinationProperty]): CfnConfigurationSetEventDestinationProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetEventDestinationProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$.html","n":"CfnConfigurationSetProps","t":"object CfnConfigurationSetProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$.html","n":"apply","t":"def apply(name: String, tags: Option[List[_ <: TagsProperty]], reputationOptions: Option[ReputationOptionsProperty], trackingOptions: Option[TrackingOptionsProperty], sendingOptions: Option[SendingOptionsProperty], deliveryOptions: Option[DeliveryOptionsProperty]): CfnConfigurationSetProps","d":"io/burkard/cdk/services/pinpointemail/CfnConfigurationSetProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$.html","n":"CfnDedicatedIpPool","t":"object CfnDedicatedIpPool","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$.html","n":"apply","t":"def apply(internalResourceId: String, tags: Option[List[_ <: TagsProperty]], poolName: Option[String])(implicit stackCtx: Stack): CfnDedicatedIpPool","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPool$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$.html","n":"CfnDedicatedIpPoolProps","t":"object CfnDedicatedIpPoolProps","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$.html","n":"apply","t":"def apply(tags: Option[List[_ <: TagsProperty]], poolName: Option[String]): CfnDedicatedIpPoolProps","d":"io/burkard/cdk/services/pinpointemail/CfnDedicatedIpPoolProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentity$.html","n":"CfnIdentity","t":"object CfnIdentity","d":"io/burkard/cdk/services/pinpointemail/CfnIdentity$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentity$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, mailFromAttributes: Option[MailFromAttributesProperty], tags: Option[List[_ <: TagsProperty]], feedbackForwardingEnabled: Option[Boolean], dkimSigningEnabled: Option[Boolean])(implicit stackCtx: Stack): CfnIdentity","d":"io/burkard/cdk/services/pinpointemail/CfnIdentity$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$.html","n":"CfnIdentityProps","t":"object CfnIdentityProps","d":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$.html","n":"apply","t":"def apply(name: String, mailFromAttributes: Option[MailFromAttributesProperty], tags: Option[List[_ <: TagsProperty]], feedbackForwardingEnabled: Option[Boolean], dkimSigningEnabled: Option[Boolean]): CfnIdentityProps","d":"io/burkard/cdk/services/pinpointemail/CfnIdentityProps$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$.html","n":"CloudWatchDestinationProperty","t":"object CloudWatchDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$.html","n":"apply","t":"def apply(dimensionConfigurations: Option[List[_]]): CloudWatchDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/CloudWatchDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$.html","n":"DeliveryOptionsProperty","t":"object DeliveryOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$.html","n":"apply","t":"def apply(sendingPoolName: Option[String]): DeliveryOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/DeliveryOptionsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$.html","n":"DimensionConfigurationProperty","t":"object DimensionConfigurationProperty","d":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$.html","n":"apply","t":"def apply(defaultDimensionValue: String, dimensionValueSource: String, dimensionName: String): DimensionConfigurationProperty","d":"io/burkard/cdk/services/pinpointemail/DimensionConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$.html","n":"EventDestinationProperty","t":"object EventDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$.html","n":"apply","t":"def apply(matchingEventTypes: List[String], pinpointDestination: Option[PinpointDestinationProperty], kinesisFirehoseDestination: Option[KinesisFirehoseDestinationProperty], enabled: Option[Boolean], cloudWatchDestination: Option[CloudWatchDestinationProperty], snsDestination: Option[SnsDestinationProperty]): EventDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/EventDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$.html","n":"KinesisFirehoseDestinationProperty","t":"object KinesisFirehoseDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$.html","n":"apply","t":"def apply(deliveryStreamArn: String, iamRoleArn: String): KinesisFirehoseDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/KinesisFirehoseDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$.html","n":"MailFromAttributesProperty","t":"object MailFromAttributesProperty","d":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$.html","n":"apply","t":"def apply(mailFromDomain: Option[String], behaviorOnMxFailure: Option[String]): MailFromAttributesProperty","d":"io/burkard/cdk/services/pinpointemail/MailFromAttributesProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$.html","n":"PinpointDestinationProperty","t":"object PinpointDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$.html","n":"apply","t":"def apply(applicationArn: Option[String]): PinpointDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/PinpointDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$.html","n":"ReputationOptionsProperty","t":"object ReputationOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$.html","n":"apply","t":"def apply(reputationMetricsEnabled: Option[Boolean]): ReputationOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/ReputationOptionsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$.html","n":"SendingOptionsProperty","t":"object SendingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$.html","n":"apply","t":"def apply(sendingEnabled: Option[Boolean]): SendingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/SendingOptionsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$.html","n":"SnsDestinationProperty","t":"object SnsDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$.html","n":"apply","t":"def apply(topicArn: String): SnsDestinationProperty","d":"io/burkard/cdk/services/pinpointemail/SnsDestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/TagsProperty$.html","n":"TagsProperty","t":"object TagsProperty","d":"io/burkard/cdk/services/pinpointemail/TagsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/TagsProperty$.html","n":"apply","t":"def apply(key: Option[String], value: Option[String]): TagsProperty","d":"io/burkard/cdk/services/pinpointemail/TagsProperty$","k":"def"},
{"l":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$.html","n":"TrackingOptionsProperty","t":"object TrackingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$","k":"object"},
{"l":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$.html","n":"apply","t":"def apply(customRedirectDomain: Option[String]): TrackingOptionsProperty","d":"io/burkard/cdk/services/pinpointemail/TrackingOptionsProperty$","k":"def"},
{"l":"docs/index.html","n":"pinpointemail","t":"pinpointemail","d":"","k":"static"}];
